@@ -1,5 +1,6 @@
 from django import template
 
+from buybackprogram.app_settings import BUYBACKPROGRAM_PRICE_SOURCE_NAME
 from buybackprogram.models import ProgramItem
 
 register = template.Library()
@@ -43,6 +44,12 @@ def setting_icons(option, program):
             "color": False,
             "message": "Raw price is taken into account when calculating values for ores.",
         },
+        "npc_price": {
+            "icon": "fa-robot",
+            "color": False,
+            "message": "Some items are using NPC prices from NPC buy orders instead of %s prices."
+            % (BUYBACKPROGRAM_PRICE_SOURCE_NAME),
+        },
         "unpacked": {
             "icon": "fa-box-open",
             "color": False,
@@ -101,6 +108,11 @@ def program_setting(program):
 
         settings.append(setting)
 
+    if program.blue_loot_npc_price or program.red_loot_npc_price:
+        setting = setting_icons("npc_price", program)
+
+        settings.append(setting)
+
     if program.use_raw_ore_value:
         setting = setting_icons("raw_ore", program)
 
